<?xml version='1.0'?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" />

<xsl:template match="/">
  <html>
    <head>
      <title>Fusebox Application Fuse Documentation</title>
      <link href="fusedocMiner.css" rel="stylesheet" type="text/css" />
    </head>
    <body>
	<div align="left"
	     style="font-family: Arial;
	            font-weight: 700;
	              font-size: 14pt;">
      Fusebox Application Fuse Documentation
    </div>
      <xsl:apply-templates select="fusedoc" />
      <br style="page-break-after:always;" />
    </body>
  </html>
</xsl:template>

<xsl:template match="fusedoc">
    <span id="fuseName"><xsl:value-of select="@fuse" /></span>
	<xsl:apply-templates select="responsibilities" />
	<xsl:apply-templates select="properties" />
	<xsl:apply-templates select="io" />
</xsl:template>

<xsl:template match="responsibilities">
  <table class="responsibilitiesTable">
    <tr>
      <th>Responsibilities</th>
    </tr>
    <tr>
      <td><xsl:apply-templates select="text()" /></td>
    </tr>
  </table>
</xsl:template>

<xsl:template match="properties">
  <table class="propertiesTable">
    <tr>
      <th colspan="7">Properties</th>
    </tr>
      <xsl:apply-templates select="property" />
	  <xsl:apply-templates select="history" />
      <xsl:apply-templates select="note" />    
  </table>
</xsl:template>

<xsl:template match="property">
  <tr>
    <td>Property: <xsl:value-of select="@name" /></td>
    <td>Value: <xsl:value-of select="@value" /></td>
    <td colspan="2">Comments: <xsl:value-of select="@comments" /></td>
    <td colspan="3"><xsl:apply-templates select="text()" /></td>
  </tr>
</xsl:template>

<xsl:template match="history">
  <tr>
    <td>History Date: <xsl:value-of select="@date" /></td>
    <td>Author: <xsl:value-of select="@author" /></td>
    <td>Email: <xsl:value-of select="@email" /></td>
    <td>Role: <xsl:value-of select="@role" /></td>
    <td>Type: <xsl:value-of select="@type" /></td>
    <td>Comments: <xsl:value-of select="@comments" /></td>
    <td><xsl:apply-templates select="text()" /></td>
  </tr>
</xsl:template>

<xsl:template match="note">
  <tr>
    <td>Note Date: <xsl:value-of select="@date" /></td>
    <td>Author: <xsl:value-of select="@author" /></td>
    <td colspan="5"><xsl:apply-templates select="text()" /></td>
  </tr>
</xsl:template>

<xsl:template match="text()">
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="io">
  <table class="ioTable">
    <tr>
      <th colspan="9">I/O</th>
    </tr>
	  <xsl:apply-templates select="in" />
	  <xsl:apply-templates select="out" />  
  </table>
</xsl:template>

<xsl:template match="in">
  <tr>
    <th colspan="9">Input</th>
  </tr>
  <xsl:apply-templates select="string | number | boolean | datetime" />
  <xsl:apply-templates select="list" />
  <xsl:apply-templates select="array" />
  <xsl:apply-templates select="structure" />
  <xsl:apply-templates select="recordset" />
  <xsl:apply-templates select="cookie" />
  <xsl:apply-templates select="file" />
</xsl:template>

<xsl:template match="out">
  <tr>
    <th colspan="9">Output</th>
  </tr>  
  <xsl:apply-templates select="string | number | boolean | datetime" />
  <xsl:apply-templates select="list" />
  <xsl:apply-templates select="array" />
  <xsl:apply-templates select="structure" />
  <xsl:apply-templates select="recordset" />
  <xsl:apply-templates select="cookie" />
  <xsl:apply-templates select="file" />
</xsl:template>

<xsl:template match="string">
  <tr>
    <td>Type: string</td>
    <td>Name: <xsl:value-of select="@name" /></td>
    <td>Scope: <xsl:value-of select="@scope" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>Mask:<xsl:value-of select="@mask" /></td>
    <td>Format:<xsl:value-of select="@format" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td>Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="number">
  <tr>
    <td>Type: number</td>
    <td>Name: <xsl:value-of select="@name" /></td>
    <td>Scope: <xsl:value-of select="@scope" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>Precision:<xsl:value-of select="@precision" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td colspan="2">Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="boolean">
  <tr>
    <td>Type: boolean</td>
    <td>Name: <xsl:value-of select="@name" /></td>
    <td>Scope: <xsl:value-of select="@scope" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td colspan="3">Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="datetime">
  <tr>
    <td>Type: datetime</td>
    <td>Name: <xsl:value-of select="@name" /></td>
    <td>Scope: <xsl:value-of select="@scope" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>Mask:<xsl:value-of select="@mask" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td colspan="2">Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="list">
  <tr>
    <td colspan="9">
      <table class="listTable">
        <tr>
          <th>Type: List</th>
          <th>Name: <xsl:value-of select="@name" /></th>
          <th>Scope: <xsl:value-of select="@scope" /></th>
          <th>Delimiters: <xsl:value-of select="@delims" /></th>
          <th>Optional: <xsl:value-of select="@optional" /></th>
          <th>Default: <xsl:value-of select="@default" /></th>
          <th>On Condition: <xsl:value-of select="@oncondition" /></th>
          <th>Format: <xsl:value-of select="@format" /></th>
          <th colspan="2">Comments: <xsl:value-of select="@comments" /></th>
        </tr>
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="cookie">
  <tr>
    <td>Type: cookie</td>
    <td>Name: <xsl:value-of select="@name" /></td>
    <td>Expires: <xsl:value-of select="@expires" /></td>
    <td>Secure: <xsl:value-of select="@secure" /></td>
    <td>Format: <xsl:value-of select="@format" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td>Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="file">
  <tr>
    <td>Type: file</td>
    <td colspan="2">Path: <xsl:value-of select="@path" /></td>
    <td>Action: <xsl:value-of select="@action" /></td>
    <td>Optional <xsl:value-of select="@optional" /></td>
    <td>Default: <xsl:value-of select="@default" /></td>
    <td>On Condition:<xsl:value-of select="@oncondition" /></td>
    <td colspan="2">Comments: <xsl:value-of select="@comments" /></td>
  </tr>
</xsl:template>

<xsl:template match="array">
  <tr>
    <td colspan="9">
      <table class="arrayTable">
        <tr>
          <th>Type: Array</th>
          <th>Name: <xsl:value-of select="@name" /></th>
          <th>Scope: <xsl:value-of select="@scope" /></th>
          <th>Optional: <xsl:value-of select="@optional" /></th>
          <th>On Condition: <xsl:value-of select="@oncondition" /></th>
          <th>Format: <xsl:value-of select="@format" /></th>
          <th colspan="4">Comments: <xsl:value-of select="@comments" /></th>
        </tr>
		<xsl:apply-templates select="string | number | boolean | datetime" />
		<xsl:apply-templates select="array" />
		<xsl:apply-templates select="structure" />
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="structure">
  <tr>
    <td colspan="9">
      <table class="structTable">
        <tr>
          <th>Type: Structure</th>
          <th>Name: <xsl:value-of select="@name" /></th>
          <th>Scope: <xsl:value-of select="@scope" /></th>
          <th>Optional: <xsl:value-of select="@optional" /></th>
          <th>On Condition: <xsl:value-of select="@oncondition" /></th>
          <th>Format: <xsl:value-of select="@format" /></th>
          <th colspan="4">Comments: <xsl:value-of select="@comments" /></th>
        </tr>
        <xsl:apply-templates select="string | number | boolean | datetime" />
 	    <xsl:apply-templates select="array" />
	    <xsl:apply-templates select="structure" />
      </table>
    </td>
  </tr>
</xsl:template>

<xsl:template match="recordset">
  <tr>
    <td colspan="9">
      <table class="recordsetTable">
        <tr>
          <th>Type: Recordset</th>
          <th>Name: <xsl:value-of select="@name" /></th>
          <th>Primary Keys: <xsl:value-of select="@primarykeys" /></th>
          <th>Scope: <xsl:value-of select="@scope" /></th>
          <th>Optional: <xsl:value-of select="@optional" /></th>
          <th>On Condition: <xsl:value-of select="@oncondition" /></th>
          <th>Format: <xsl:value-of select="@format" /></th>
          <th colspan="2">Comments: <xsl:value-of select="@comments" /></th>
        </tr>
        <xsl:apply-templates select="string | number | boolean | datetime" />
      </table>
    </td>
  </tr>
</xsl:template>

</xsl:stylesheet>
